/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+
#+     Glade / Gtk Programming
#+
#+     Copyright (C) 2020 - 2026 by Kevin C. O'Kane
#+
#+     Kevin C. O'Kane
#+     kc.okane@gmail.com
#+     https://www.cs.uni.edu/~okane
#+     http://threadsafebooks.com/
#+
#+ This program is free software; you can redistribute it and/or modify
#+ it under the terms of the GNU General Public License as published by
#+ the Free Software Foundation; either version 2 of the License, or
#+ (at your option) any later version.
#+
#+ This program is distributed in the hope that it will be useful,
#+ but WITHOUT ANY WARRANTY; without even the implied warranty of
#+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#+ GNU General Public License for more details.
#+
#+ You should have received a copy of the GNU General Public License
#+ along with this program; if not, write to the Free Software
#+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#+
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//	July 8, 2026

#ifndef COMMON_WIDGETS_H
#define COMMON_WIDGETS_H

int skip;

double vlc_moved;

GtkWidget *clip_duration_spinner;

GtkWidget *crop_adj;

GtkWidget *fx12;

GtkWidget *sequential;

GtkWidget *message1;

GtkWidget *insert_panel;
GtkWidget *adjust_video;
GtkWidget *Top1;

GtkWidget *opt_panel;
GtkWidget *ovl_fixed;
GtkWidget *ovl_fixed1;

GtkWidget *pg;

GtkWidget *current_stack = NULL;

GtkStack *stack2;
GtkWidget *sw1;

GtkStack *stackleft;

GtkWidget *duration_spin;

GtkWidget *current_dir;

GtkWidget *p1cover;
GtkWidget *p4cover;
GtkWidget *p7cover;
GtkWidget *p10cover;

GtkWidget *tile_back;
GtkWidget *tile_first;
GtkWidget *tile_forward;
GtkWidget *tile_last;

GtkWidget *clip_x, *clip_y;


GtkWidget *p1name;
GtkWidget *p2name;
GtkWidget *p3name;
GtkWidget *p4name;
GtkWidget *p5name;
GtkWidget *p6name;
GtkWidget *p7name;
GtkWidget *p8name;
GtkWidget *p9name;
GtkWidget *p10name;
GtkWidget *p11name;
GtkWidget *p12name;

GtkWidget *nowPlaying;
GtkWidget *p1Clip;
GtkWidget *p2Clip;
GtkWidget *p3Clip;
GtkWidget *p4Clip;
GtkWidget *p5Clip;
GtkWidget *p6Clip;
GtkWidget *p7Clip;
GtkWidget *p8Clip;
GtkWidget *p9Clip;
GtkWidget *p10Clip;
GtkWidget *p11Clip;
GtkWidget *p12Clip;

GtkWidget *play_clip1;
GtkWidget *frames_per_second;
GtkWidget *Top1;
GtkWidget *overlay_end_lbl;
GtkWidget *overlay_end;
GtkWidget *five_speed;
GtkWidget *quad_speed;
GtkWidget *tripple_speed;
GtkWidget *double_speed;
GtkWidget *full_speed;
GtkWidget *half_speed;
GtkWidget *quarter_speed;
GtkWidget *eighth_speed;
GtkWidget *frame_forward1;
GtkWidget *frame_forward2;
GtkWidget *loop_stream;
GtkWidget *out_fade;
GtkWidget *in_fade;
GtkWidget *granularity;
GtkWidget *zippy_toy;
GtkWidget *pgedit_back;
GtkWidget *pgedit_back1;
GtkWidget *rantran;
GtkWidget *select_all;
GtkWidget *clear_all;
GtkWidget *monochrome;
GtkWidget *sharp_y;
GtkWidget *sharp_x;
GtkWidget *sharp_amount;
GtkWidget *text_start;
GtkWidget *text_end;
GtkWidget *text_label;
GtkWidget *dbox4_tv;
GtkWidget *dbox4_vp;
GtkWidget *dbox4_sw;
GtkWidget *edge_canny;
GtkWidget *edge_wires;
GtkWidget *edge_colormix;
GtkWidget *view_log;
// GtkWidget *clip_length;
GtkWidget *vid_custom;
GtkWidget *vid_640x480;
GtkWidget *vid_720x480;
GtkWidget *vid_1280x720;
GtkWidget *vid_1920x1080;
GtkWidget *vid_3840x2160;
GtkWidget *frame_next;
GtkWidget *strip_audio;
GtkWidget *crop_left;
GtkWidget *crop_right;
GtkWidget *crop_top;
GtkWidget *crop_bottom;
GtkWidget *full_speed;
GtkWidget *posLbl;
GtkWidget *frame_grab;
GtkWidget *join_videos;
GtkWidget *crop_full;
GtkWidget *clear_clip;
GtkWidget *snapshot;
GtkWidget *end_mark;
GtkWidget *start_mark;
GtkWidget *make_clip;
GtkWidget *join_group;
GtkWidget *top1_back1;
GtkWidget *join_group2;
GtkWidget *join_group3;
GtkWidget *join_group4;
GtkWidget *join_group5;
GtkWidget *join_group6;
GtkWidget *join_group7;
GtkWidget *join_group8;
GtkWidget *join_group9;
GtkWidget *join_group10;
GtkWidget *join_group11;
GtkWidget *join_group12;
GtkWidget *join_group13;
GtkWidget *join_group14;
GtkWidget *join_group15;
GtkWidget *join_group16;
GtkWidget *join_group17;
GtkWidget *join_group18;
GtkWidget *join_group19;
GtkWidget *join_group20;
GtkWidget *join_group21;
GtkWidget *join_group22;
GtkWidget *join_group23;
GtkWidget *join_group1;
GtkWidget *ct_fixed;
GtkWidget *ed_fixed;
GtkWidget *crop_reset;
GtkWidget *pg_edit;
GtkWidget *pg_fixed;
GtkWidget *mini_mode;
GtkWidget *time_of_day;
GtkWidget *cam0_image = NULL;
GtkWidget *audio;
GtkWidget *background;
GtkWidget *button10;
GtkWidget *button11;
GtkWidget *button12;
GtkWidget *button13;
GtkWidget *button14;
GtkWidget *button15;
GtkWidget *button2;
GtkWidget *button3;
GtkWidget *button5;
GtkWidget *button6;
GtkWidget *button[8];
GtkWidget *button8;
GtkWidget *button9;
GtkWidget *calibrateLbl;
GtkWidget *cbox1;
GtkWidget *check1;
GtkWidget *check10;
GtkWidget *check11;
GtkWidget *check12;
GtkWidget *check2;
GtkWidget *check3;
GtkWidget *check4;
GtkWidget *check5;
GtkWidget *check6;
GtkWidget *check7;
GtkWidget *check8;
GtkWidget *check9;
GtkWidget *choose1;
GtkWidget *classical;
GtkWidget *clevel;
GtkWidget *club;
GtkWidget *controls;
GtkWidget *dance;
GtkWidget *del10;
GtkWidget *del11;
GtkWidget *del12;
GtkWidget *del13;
GtkWidget *del14;
GtkWidget *del15;
GtkWidget *del2;
GtkWidget *del3;
GtkWidget *del4;
GtkWidget *del7;
GtkWidget *del8;
GtkWidget *del9;
GtkWidget *draw3;
GtkWidget *clip_markers;
GtkWidget *empty;
GtkWidget *eqReset;
GtkWidget *first;
GtkWidget *fixed1;
GtkWidget *fixed2;
GtkWidget *fixed_slides;
GtkWidget *g_btn_play;
GtkWidget *g_btn_play2;
GtkWidget *g_dbox4;
GtkWidget *g_image1;
GtkWidget *g_scale1;
GtkWidget *haltProgram;
GtkWidget *highLabel;
GtkWidget *horLabel;
GtkWidget *lbl1;
GtkWidget *lbl10;
GtkWidget *lbl11;
GtkWidget *lbl12;
GtkWidget *lbl2;
GtkWidget *lbl3;
GtkWidget *lbl4;
GtkWidget *lbl5;
GtkWidget *lbl6;
GtkWidget *lbl7;
GtkWidget *lbl8;
GtkWidget *lbl9;
GtkWidget *live;
GtkWidget *more;
GtkWidget *narrow;
GtkWidget *rampSpeedDown;
GtkWidget *rampSpeedUp;
GtkWidget *sgrStudio;
GtkWidget *sock1;
GtkWidget *sort1;  // alpha sort
GtkWidget *source;
GtkWidget *vlcPosition;
GtkWidget *window;
GtkWidget *scroll = NULL;
GtkWidget *rayLbl;
GtkWidget *frame1;
GtkWidget *drawV;
GtkWidget *micGain;
GtkWidget *xbox2;

libvlc_instance_t	*inst = NULL;
libvlc_media_player_t	*mediaPlayer = NULL;
libvlc_media_t		*media = NULL;
libvlc_equalizer_t	*equalizer = NULL;

GtkColorButton *text_color;

GdkColor color;

GtkTextBuffer *TextBuffer;

GtkAdjustment *adjustment37;
GtkAdjustment *adjustment43;
GtkAdjustment *adjustment33;
GtkAdjustment *adjustment32;
GtkAdjustment *adjustment31;
GtkAdjustment *adjustment30;
GtkAdjustment *adjustment29;
GtkAdjustment *adjustment28;
GtkAdjustment *adjustment27;
GtkAdjustment *adjustment26;
GtkAdjustment *adjustment25;
GtkAdjustment *adjustment23;
GtkAdjustment *adjustment22;
GtkAdjustment *adjustment21;
GtkAdjustment *adjustment20;
GtkAdjustment *adjustment54;
GtkAdjustment *adjustment40;
GtkAdjustment *adjustment6;
GtkAdjustment *adjustment7;
GtkAdjustment *adjustment1;
GtkAdjustment *adjustment8;
GtkAdjustment *adjustment9;
GtkAdjustment *adjustment10;
GtkAdjustment *adjustment11;
GtkAdjustment *adjustment12;
GtkAdjustment *adjustment13; // back_trans
GtkAdjustment *adjustment14; // text_start
GtkAdjustment *adjustment15; // text_end
GtkAdjustment *adjustment16; // text_size

GtkEntry *OverlayEntry1;
GtkEntry *OverlayEntry2;
GtkEntry *OverlayEntry3;
GtkEntry *OverlayEntry4;
GtkEntry *OverlayEntry5;
GtkEntry *g_dbox5Entry;

GdkPixbuf *pixbuf;
GdkPixbuf *cambuf;

GdkWindow *gdk_window;

GError *err;

GtkBuilder      *builder;

int mouse_ul_x, mouse_ul_y;
int mouse_lr_x, mouse_lr_y;

GtkWidget       *p1;
GtkWidget       *p10;
GtkWidget       *p11;
GtkWidget       *p12;
GtkWidget       *p2;
GtkWidget       *p3;
GtkWidget       *p4;
GtkWidget       *p5;
GtkWidget       *p6;
GtkWidget       *p7;
GtkWidget       *p8;
GtkWidget       *p9;

GtkWidget       *scroll2 = NULL;

GtkWidget	*search_scroll;

GdkPixbuf       *pix;       // scaled pictures
GdkPixbuf       *pixIn;     // original (unscaled) pictures


#endif
